==> python-dateparser-0.7.6-1-any.pkg.tar.xz: usr/lib/python3.8/site-packages/dateparser/data/date_translation_data/gd.py <==
# -*- coding: utf-8 -*-
info = {
    "name": "gd",
    "date_order": "DMY",
    "january": [
        "am faoilleach",
        "faoi",
        "dhen fhaoilleach"
    ],
    "february": [
        "an gearran",
        "gearr",
        "dhen ghearran"
    ],
    "march": [
        "am màrt",
        "màrt",
        "dhen mhàrt"
    ],
    "april": [
        "an giblean",
        "gibl",
        "dhen ghiblean"
    ],
    "may": [
        "an cèitean",
        "cèit",
        "dhen chèitean"
    ],
    "june": [
        "an t-ògmhios",
        "ògmh",
        "dhen ògmhios"
    ],
    "july": [
        "an t-iuchar",
        "iuch",
        "dhen iuchar"
    ],
    "august": [
        "an lùnastal",
        "lùna",
        "dhen lùnastal"
    ],
    "september": [
        "an t-sultain",
        "sult",
        "dhen t-sultain"
    ],
    "october": [
        "an dàmhair",
        "dàmh",
        "dhen dàmhair"
    ],
    "november": [
        "an t-samhain",
        "samh",
        "dhen t-samhain"
    ],
    "december": [
        "an dùbhlachd",
        "dùbh",
        "dhen dùbhlachd"
    ],
    "monday": [
        "diluain",
        "dil"
    ],
    "tuesday": [
        "dimàirt",
        "dim"
    ],
    "wednesday": [
        "diciadain",
        "dic"
    ],
    "thursday": [
        "diardaoin",
        "dia"
    ],
    "friday": [
        "dihaoine",
        "dih"
    ],
    "saturday": [
        "disathairne",
        "dis"
    ],
    "sunday": [
        "didòmhnaich",
        "did"
    ],
    "am": [
        "m"
    ],
    "pm": [
        "f"
    ],
    "year": [
        "bliadhna",
        "blia",
        "bl"
    ],
    "month": [
        "mìos",
        "mì"
    ],
    "week": [
        "seachdain",
        "seachd",
        "sn"
    ],
    "day": [
        "latha",
        "là"
    ],
    "hour": [
        "uair a thìde",
        "uair",
        "u"
    ],
    "minute": [
        "mionaid",
        "mion",
        "m"
    ],
    "second": [
        "diog",
        "d"
    ],
    "relative-type": {
        "1 year ago": [
            "an-uiridh",
            "an-uir"
        ],
        "0 year ago": [
            "am bliadhna",
            "am bl"
        ],
        "in 1 year": [
            "an ath-bhliadhna",
            "an ath-bhl"
        ],
        "1 month ago": [
            "am mìos seo chaidh",
            "am mìos sa chaidh",
            "mì ch"
        ],
        "0 month ago": [
            "am mìos seo",
            "am mì seo"
        ],
        "in 1 month": [
            "an ath-mhìos",
            "ath-mhì"
        ],
        "1 week ago": [
            "an t-seachdain seo chaidh",
            "seachd sa chaidh",
            "sn ch"
        ],
        "0 week ago": [
            "an t-seachdain seo",
            "an t-seachd seo",
            "an t-sn seo"
        ],
        "in 1 week": [
            "an ath-sheachdain",
            "an ath-sheachd",
            "ath-shn"
        ],
        "1 day ago": [
            "an-dè"
        ],
        "0 day ago": [
            "an-diugh"
        ],
        "in 1 day": [
            "a-màireach"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 second ago": [
            "an-dràsta"
        ]
    },
    "relative-type-regex": {
        "in \\1 year": [
            "an ceann (\\d+) bhliadhna",
            "an ceann (\\d+) bliadhna",
            "an (\\d+) bhlia",
            "an (\\d+) blia"
        ],
        "\\1 year ago": [
            "(\\d+) bhliadhna air ais",
            "(\\d+) bliadhna air ais",
            "o (\\d+) bhlia",
            "o (\\d+) blia"
        ],
        "in \\1 month": [
            "an ceann (\\d+) mhìosa",
            "an ceann (\\d+) mìosa",
            "an (\\d+) mhìos",
            "an (\\d+) mìos"
        ],
        "\\1 month ago": [
            "(\\d+) mhìos air ais",
            "(\\d+) mìos air ais",
            "o (\\d+) mhìos",
            "o (\\d+) mìos"
        ],
        "in \\1 week": [
            "an ceann (\\d+) seachdain",
            "an (\\d+) sheachd",
            "an (\\d+) seachd"
        ],
        "\\1 week ago": [
            "(\\d+) seachdain air ais",
            "o (\\d+) sheachd",
            "o (\\d+) seachd"
        ],
        "in \\1 day": [
            "an ceann (\\d+) latha",
            "an (\\d+) là"
        ],
        "\\1 day ago": [
            "(\\d+) latha air ais",
            "o (\\d+) là"
        ],
        "in \\1 hour": [
            "an ceann (\\d+) uair a thìde",
            "an (\\d+) uair"
        ],
        "\\1 hour ago": [
            "(\\d+) uair a thìde air ais",
            "o (\\d+) uair"
        ],
        "in \\1 minute": [
            "an ceann (\\d+) mhionaid",
            "an ceann (\\d+) mionaid",
            "an (\\d+) mhion",
            "an (\\d+) mion"
        ],
        "\\1 minute ago": [
            "(\\d+) mhionaid air ais",
            "(\\d+) mionaid air ais",
            "o (\\d+) mhion",
            "o (\\d+) mion"
        ],
        "in \\1 second": [
            "an ceann (\\d+) diog",
            "an (\\d+) diog"
        ],
        "\\1 second ago": [
            "(\\d+) diog air ais",
            "o (\\d+) diog"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        ".",
        ",",
        ";",
        "-",
        "/",
        "'",
        "|",
        "@",
        "[",
        "]",
        "，"
    ]
}

==> python-dateparser-1.1.1-1-any.pkg.tar.xz: usr/lib/python3.10/site-packages/dateparser/data/date_translation_data/gd.py <==
info = {
    "name": "gd",
    "date_order": "DMY",
    "january": [
        "am faoilleach",
        "dhen fhaoilleach",
        "faoi"
    ],
    "february": [
        "an gearran",
        "dhen ghearran",
        "gearr"
    ],
    "march": [
        "am màrt",
        "dhen mhàrt",
        "màrt"
    ],
    "april": [
        "an giblean",
        "dhen ghiblean",
        "gibl"
    ],
    "may": [
        "an cèitean",
        "cèit",
        "dhen chèitean"
    ],
    "june": [
        "an t-ògmhios",
        "dhen ògmhios",
        "ògmh"
    ],
    "july": [
        "an t-iuchar",
        "dhen iuchar",
        "iuch"
    ],
    "august": [
        "an lùnastal",
        "dhen lùnastal",
        "lùna"
    ],
    "september": [
        "an t-sultain",
        "dhen t-sultain",
        "sult"
    ],
    "october": [
        "an dàmhair",
        "dhen dàmhair",
        "dàmh"
    ],
    "november": [
        "an t-samhain",
        "dhen t-samhain",
        "samh"
    ],
    "december": [
        "an dùbhlachd",
        "dhen dùbhlachd",
        "dùbh"
    ],
    "monday": [
        "dil",
        "diluain"
    ],
    "tuesday": [
        "dim",
        "dimàirt"
    ],
    "wednesday": [
        "dic",
        "diciadain"
    ],
    "thursday": [
        "dia",
        "diardaoin"
    ],
    "friday": [
        "dih",
        "dihaoine"
    ],
    "saturday": [
        "dis",
        "disathairne"
    ],
    "sunday": [
        "did",
        "didòmhnaich"
    ],
    "am": [
        "m"
    ],
    "pm": [
        "f"
    ],
    "year": [
        "bl",
        "blia",
        "bliadhna"
    ],
    "month": [
        "mì",
        "mìos"
    ],
    "week": [
        "seachd",
        "seachdain",
        "sn"
    ],
    "day": [
        "latha",
        "là"
    ],
    "hour": [
        "u",
        "uair",
        "uair a thìde"
    ],
    "minute": [
        "m",
        "mion",
        "mionaid"
    ],
    "second": [
        "d",
        "diog"
    ],
    "relative-type": {
        "0 day ago": [
            "an-diugh"
        ],
        "0 hour ago": [
            "this hour"
        ],
        "0 minute ago": [
            "this minute"
        ],
        "0 month ago": [
            "am mì seo",
            "am mìos seo"
        ],
        "0 second ago": [
            "an-dràsta"
        ],
        "0 week ago": [
            "an t-seachd seo",
            "an t-seachdain seo",
            "an t-sn seo"
        ],
        "0 year ago": [
            "am bl",
            "am bliadhna"
        ],
        "1 day ago": [
            "an-dè"
        ],
        "1 month ago": [
            "am mìos sa chaidh",
            "am mìos seo chaidh",
            "mì ch"
        ],
        "1 week ago": [
            "an t-seachdain seo chaidh",
            "seachd sa chaidh",
            "sn ch"
        ],
        "1 year ago": [
            "an-uir",
            "an-uiridh"
        ],
        "in 1 day": [
            "a-màireach"
        ],
        "in 1 month": [
            "an ath-mhìos",
            "ath-mhì"
        ],
        "in 1 week": [
            "an ath-sheachd",
            "an ath-sheachdain",
            "ath-shn"
        ],
        "in 1 year": [
            "an ath-bhl",
            "an ath-bhliadhna"
        ]
    },
    "relative-type-regex": {
        "\\1 day ago": [
            "o (\\d+) là",
            "(\\d+) latha air ais"
        ],
        "\\1 hour ago": [
            "o (\\d+) uair",
            "(\\d+) uair a thìde air ais"
        ],
        "\\1 minute ago": [
            "o (\\d+) mhion",
            "o (\\d+) mion",
            "(\\d+) mhionaid air ais",
            "(\\d+) mionaid air ais"
        ],
        "\\1 month ago": [
            "o (\\d+) mhìos",
            "o (\\d+) mìos",
            "(\\d+) mhìos air ais",
            "(\\d+) mìos air ais"
        ],
        "\\1 second ago": [
            "o (\\d+) diog",
            "(\\d+) diog air ais"
        ],
        "\\1 week ago": [
            "o (\\d+) seachd",
            "o (\\d+) sheachd",
            "(\\d+) seachdain air ais"
        ],
        "\\1 year ago": [
            "o (\\d+) bhlia",
            "o (\\d+) blia",
            "(\\d+) bhliadhna air ais",
            "(\\d+) bliadhna air ais"
        ],
        "in \\1 day": [
            "an ceann (\\d+) latha",
            "an (\\d+) là"
        ],
        "in \\1 hour": [
            "an ceann (\\d+) uair a thìde",
            "an (\\d+) uair"
        ],
        "in \\1 minute": [
            "an ceann (\\d+) mhionaid",
            "an ceann (\\d+) mionaid",
            "an (\\d+) mhion",
            "an (\\d+) mion"
        ],
        "in \\1 month": [
            "an ceann (\\d+) mhìosa",
            "an ceann (\\d+) mìosa",
            "an (\\d+) mhìos",
            "an (\\d+) mìos"
        ],
        "in \\1 second": [
            "an ceann (\\d+) diog",
            "an (\\d+) diog"
        ],
        "in \\1 week": [
            "an ceann (\\d+) seachdain",
            "an (\\d+) seachd",
            "an (\\d+) sheachd"
        ],
        "in \\1 year": [
            "an ceann (\\d+) bhliadhna",
            "an ceann (\\d+) bliadhna",
            "an (\\d+) bhlia",
            "an (\\d+) blia"
        ]
    },
    "locale_specific": {},
    "skip": [
        " ",
        "'",
        ",",
        "-",
        ".",
        "/",
        ";",
        "@",
        "[",
        "]",
        "|",
        "，"
    ]
}
